(**************************************************************)
(*
 *  Ensemble, 1.10
 *  Copyright 2001 Cornell University, Hebrew University
 *  All rights reserved.
 *
 *  See ensemble/doc/license.txt for further information.
 *)
(**************************************************************)
(**************************************************************)
(* VERSION.ML *)
(* Author: Mark Hayden, 6/96 *)
(**************************************************************)

type id = string

let id = "1.10"

let string_of_id = Util.ident
